==> dde-network-core_1.0.57.orig.tar.xz: dde-network-core-1.0.57/dock-network-plugin/translations/dock-network-plugin_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="da" version="2.1">
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Netværk</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Band</source>
        <translation>Bånd</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Grænseflade</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmaske</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primær DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Præfiks</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hastighed</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Enhed deaktiveret</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Tilsluttet men ingen internetadgang</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ikke tilsluttet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netværkskablet er frakoblet</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Opretter forbindelse</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificering</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Indhenter IP-adresse</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Tilsluttet</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Afbrudt</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Mislykkedet</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kablet netværk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kablet netværk %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Trådløst netværk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Trådløst netværk %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Enhed deaktiveret</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netværkskablet er frakoblet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ikke tilsluttet</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Opretter forbindelse</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Tilsluttet men ingen internetadgang</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Deaktivér kablet forbindelse</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Aktivér kablet forbindelse</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Deaktivér trådløs forbindelse</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Aktivér trådløs forbindelse</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Deaktivér netværk</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Aktivér netværk</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netværksindstillinger</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.5.orig.tar.xz: dde-network-core-1.1.5/dock-network-plugin/translations/dock-network-plugin_da.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="da">
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Trådløst netværk</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Kablet netværk</translation>
    </message>
</context>
<context>
    <name>NetworkPlugin</name>
    <message>
        <source>Network</source>
        <translation>Netværk</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Opret forbindelse til skjult netværk</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Adgangskode</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annuller</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Opret forbindelse</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Security Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bånd</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Grænseflade</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>Netmaske</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Gateway</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>Primær DNS</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Præfiks</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Hastighed</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Enhed deaktiveret</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Tilsluttet men ingen internetadgang</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ikke tilsluttet</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netværkskablet er frakoblet</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Opretter forbindelse</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Autentificering</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Indhenter IP-adresse</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>Tilsluttet</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>Afbrudt</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Failed</source>
        <translation>Mislykkedet</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Kablet netværk</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Kablet netværk %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Trådløst netværk</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Trådløst netværk %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Enhed deaktiveret</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Netværkskablet er frakoblet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Ikke tilsluttet</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Opretter forbindelse</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Tilsluttet men ingen internetadgang</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>IP conflict</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Deaktivér kablet forbindelse</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Aktivér kablet forbindelse</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Deaktivér trådløs forbindelse</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Aktivér trådløs forbindelse</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Deaktivér netværk</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Aktivér netværk</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Netværksindstillinger</translation>
    </message>
</context>
</TS>
